from .controlledcomponent import ControlledComponent


class VCVS(ControlledComponent):

    type = "E"
